@@ -229,8 +229,6 @@ def add_two_button_alarm( message = "We are HERE!"):
     return cookie
 
 def cell_signal_handler(*args):
-#    print str(args)
- #   print "args: ", "%s,%s,%s,%s,%s" % (args[0], args[1], args[2], args[3], args[4])
     if( myapp.enableLogging ):
         myapp.fileObj.write( time() + '--> ' + str(args[4]) + ', ' + str(args[3]) + ', ' + str(args[2]) + '\n' )
 
@@ -251,17 +249,14 @@ def cell_signal_handler(*args):
                 myapp.ui.checkBoxAlarm.setTristate(False)
                 add_two_button_alarm()
                 #sys.exit(myapp.exec_())
-    #            myapp.ui.centralwidget.setEnabled(True)
+                #myapp.ui.centralwidget.setEnabled(True)
 
             # Even if there is no alarm, give soem feedback to UI that we're arrived!
             myapp.ui.pushButtonStart.setText("We are HERE!")
 
-    if( myapp.enableGSMAlarm and (args[3] == 6) ):
+    if( myapp.enableGSMAlarm and (args[3] != 0 and args[4] != 0) ):
         myapp.enableGSMAlarm = False
-#        print "setting GSM alarm state to false"
-#        print(dir(myapp.ui.checkBoxGSMAlarm))
         myapp.ui.checkBoxGSMAlarm.setChecked(False)
-#        print "isChecked", myapp.ui.checkBoxGSMAlarm.isChecked()
         add_two_button_alarm("GSM network available")
 
 #ideas: replace cellid with name if it was saved before.
@@ -273,4 +268,3 @@ if __name__ == '__main__':
     myapp = MyForm()
     myapp.show()
     sys.exit(app.exec_())
-
